==> ses-1.60.0-sources.jar: software/amazon/awscdk/services/ses/CfnConfigurationSetEventDestinationProps.java <==
package software.amazon.awscdk.services.ses;

/**
 * Properties for defining a `AWS::SES::ConfigurationSetEventDestination`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-configurationseteventdestination.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.445Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ses.$Module.class, fqn = "@aws-cdk/aws-ses.CfnConfigurationSetEventDestinationProps")
@software.amazon.jsii.Jsii.Proxy(CfnConfigurationSetEventDestinationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnConfigurationSetEventDestinationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::SES::ConfigurationSetEventDestination.ConfigurationSetName`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-configurationseteventdestination.html#cfn-ses-configurationseteventdestination-configurationsetname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getConfigurationSetName();

    /**
     * `AWS::SES::ConfigurationSetEventDestination.EventDestination`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-configurationseteventdestination.html#cfn-ses-configurationseteventdestination-eventdestination
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getEventDestination();

    /**
     * @return a {@link Builder} of {@link CfnConfigurationSetEventDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnConfigurationSetEventDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnConfigurationSetEventDestinationProps> {
        private java.lang.String configurationSetName;
        private java.lang.Object eventDestination;

        /**
         * Sets the value of {@link CfnConfigurationSetEventDestinationProps#getConfigurationSetName}
         * @param configurationSetName `AWS::SES::ConfigurationSetEventDestination.ConfigurationSetName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configurationSetName(java.lang.String configurationSetName) {
            this.configurationSetName = configurationSetName;
            return this;
        }

        /**
         * Sets the value of {@link CfnConfigurationSetEventDestinationProps#getEventDestination}
         * @param eventDestination `AWS::SES::ConfigurationSetEventDestination.EventDestination`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder eventDestination(software.amazon.awscdk.core.IResolvable eventDestination) {
            this.eventDestination = eventDestination;
            return this;
        }

        /**
         * Sets the value of {@link CfnConfigurationSetEventDestinationProps#getEventDestination}
         * @param eventDestination `AWS::SES::ConfigurationSetEventDestination.EventDestination`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder eventDestination(software.amazon.awscdk.services.ses.CfnConfigurationSetEventDestination.EventDestinationProperty eventDestination) {
            this.eventDestination = eventDestination;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnConfigurationSetEventDestinationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnConfigurationSetEventDestinationProps build() {
            return new Jsii$Proxy(configurationSetName, eventDestination);
        }
    }

    /**
     * An implementation for {@link CfnConfigurationSetEventDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnConfigurationSetEventDestinationProps {
        private final java.lang.String configurationSetName;
        private final java.lang.Object eventDestination;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.configurationSetName = this.jsiiGet("configurationSetName", java.lang.String.class);
            this.eventDestination = this.jsiiGet("eventDestination", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String configurationSetName, final java.lang.Object eventDestination) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.configurationSetName = java.util.Objects.requireNonNull(configurationSetName, "configurationSetName is required");
            this.eventDestination = java.util.Objects.requireNonNull(eventDestination, "eventDestination is required");
        }

        @Override
        public java.lang.String getConfigurationSetName() {
            return this.configurationSetName;
        }

        @Override
        public java.lang.Object getEventDestination() {
            return this.eventDestination;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("configurationSetName", om.valueToTree(this.getConfigurationSetName()));
            data.set("eventDestination", om.valueToTree(this.getEventDestination()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ses.CfnConfigurationSetEventDestinationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnConfigurationSetEventDestinationProps.Jsii$Proxy that = (CfnConfigurationSetEventDestinationProps.Jsii$Proxy) o;

            if (!configurationSetName.equals(that.configurationSetName)) return false;
            return this.eventDestination.equals(that.eventDestination);
        }

        @Override
        public int hashCode() {
            int result = this.configurationSetName.hashCode();
            result = 31 * result + (this.eventDestination.hashCode());
            return result;
        }
    }
}

==> ses-1.173.0-sources.jar: software/amazon/awscdk/services/ses/CfnConfigurationSetEventDestinationProps.java <==
package software.amazon.awscdk.services.ses;

/**
 * Properties for defining a `CfnConfigurationSetEventDestination`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ses.*;
 * CfnConfigurationSetEventDestinationProps cfnConfigurationSetEventDestinationProps = CfnConfigurationSetEventDestinationProps.builder()
 *         .configurationSetName("configurationSetName")
 *         .eventDestination(EventDestinationProperty.builder()
 *                 .matchingEventTypes(List.of("matchingEventTypes"))
 *                 // the properties below are optional
 *                 .cloudWatchDestination(CloudWatchDestinationProperty.builder()
 *                         .dimensionConfigurations(List.of(DimensionConfigurationProperty.builder()
 *                                 .defaultDimensionValue("defaultDimensionValue")
 *                                 .dimensionName("dimensionName")
 *                                 .dimensionValueSource("dimensionValueSource")
 *                                 .build()))
 *                         .build())
 *                 .enabled(false)
 *                 .kinesisFirehoseDestination(KinesisFirehoseDestinationProperty.builder()
 *                         .deliveryStreamArn("deliveryStreamArn")
 *                         .iamRoleArn("iamRoleArn")
 *                         .build())
 *                 .name("name")
 *                 .snsDestination(SnsDestinationProperty.builder()
 *                         .topicArn("topicArn")
 *                         .build())
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:30.590Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ses.$Module.class, fqn = "@aws-cdk/aws-ses.CfnConfigurationSetEventDestinationProps")
@software.amazon.jsii.Jsii.Proxy(CfnConfigurationSetEventDestinationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnConfigurationSetEventDestinationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the configuration set that contains the event destination.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getConfigurationSetName();

    /**
     * The event destination object.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getEventDestination();

    /**
     * @return a {@link Builder} of {@link CfnConfigurationSetEventDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnConfigurationSetEventDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnConfigurationSetEventDestinationProps> {
        java.lang.String configurationSetName;
        java.lang.Object eventDestination;

        /**
         * Sets the value of {@link CfnConfigurationSetEventDestinationProps#getConfigurationSetName}
         * @param configurationSetName The name of the configuration set that contains the event destination. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configurationSetName(java.lang.String configurationSetName) {
            this.configurationSetName = configurationSetName;
            return this;
        }

        /**
         * Sets the value of {@link CfnConfigurationSetEventDestinationProps#getEventDestination}
         * @param eventDestination The event destination object. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder eventDestination(software.amazon.awscdk.core.IResolvable eventDestination) {
            this.eventDestination = eventDestination;
            return this;
        }

        /**
         * Sets the value of {@link CfnConfigurationSetEventDestinationProps#getEventDestination}
         * @param eventDestination The event destination object. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder eventDestination(software.amazon.awscdk.services.ses.CfnConfigurationSetEventDestination.EventDestinationProperty eventDestination) {
            this.eventDestination = eventDestination;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnConfigurationSetEventDestinationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnConfigurationSetEventDestinationProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnConfigurationSetEventDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnConfigurationSetEventDestinationProps {
        private final java.lang.String configurationSetName;
        private final java.lang.Object eventDestination;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.configurationSetName = software.amazon.jsii.Kernel.get(this, "configurationSetName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.eventDestination = software.amazon.jsii.Kernel.get(this, "eventDestination", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.configurationSetName = java.util.Objects.requireNonNull(builder.configurationSetName, "configurationSetName is required");
            this.eventDestination = java.util.Objects.requireNonNull(builder.eventDestination, "eventDestination is required");
        }

        @Override
        public final java.lang.String getConfigurationSetName() {
            return this.configurationSetName;
        }

        @Override
        public final java.lang.Object getEventDestination() {
            return this.eventDestination;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("configurationSetName", om.valueToTree(this.getConfigurationSetName()));
            data.set("eventDestination", om.valueToTree(this.getEventDestination()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ses.CfnConfigurationSetEventDestinationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnConfigurationSetEventDestinationProps.Jsii$Proxy that = (CfnConfigurationSetEventDestinationProps.Jsii$Proxy) o;

            if (!configurationSetName.equals(that.configurationSetName)) return false;
            return this.eventDestination.equals(that.eventDestination);
        }

        @Override
        public final int hashCode() {
            int result = this.configurationSetName.hashCode();
            result = 31 * result + (this.eventDestination.hashCode());
            return result;
        }
    }
}
